@@ -1,13 +1,14 @@
 """test Intel Quartus flow"""
+
+import logging
 import os
 import tempfile
-import logging
 from pathlib import Path
 
 from xeda import Design
+from xeda.flow import FPGA
 from xeda.flow_runner import DefaultRunner
 from xeda.flows import Quartus
-from xeda.flow import FPGA
 from xeda.flows.quartus import parse_csv, try_num
 
 TESTS_DIR = Path(__file__).parent.absolute()
@@ -45,7 +46,7 @@ def test_parse_csv():
             "Block Memory Bits",
             "Pins",
             "I/O Registers",
-        }
+        },
         # ['Logic Cells', 'Memory Bits', 'M10Ks', 'M9Ks', 'DSP Elements', 'ALMs needed [=A-B+C]',
         #                     'Combinational ALUTs', 'ALMs used for memory', 'DSP Blocks', 'Pins'
         #                     'LUT-Only LCs',	'Register-Only LCs', 'LUT/Register LCs', 'Block Memory Bits']
@@ -130,6 +131,7 @@ def test_quartus_synth_py() -> None:
         print("Xeda run dir: ", run_dir)
         xeda_runner = DefaultRunner(run_dir, debug=True)
         flow = xeda_runner.run_flow(Quartus, design, settings)
+        assert flow is not None, "run_flow returned None"
         settings_json = flow.run_path / "settings.json"
         results_json = flow.run_path / "results.json"
         assert settings_json.exists()
