@@ -4,9 +4,9 @@ import tempfile
 from pathlib import Path
 
 from xeda import Design
+from xeda.flow import FPGA
 from xeda.flow_runner import DefaultRunner
 from xeda.flows import VivadoSynth
-from xeda.flow import FPGA
 from xeda.flows.vivado.vivado_synth import parse_hier_util, vivado_synth_generics
 
 TESTS_DIR = Path(__file__).parent.absolute()
@@ -15,8 +15,6 @@ EXAMPLES_DIR = TESTS_DIR.parent / "examples"
 
 
 def test_vivado_synth_template() -> None:
-    path = RESOURCES_DIR / "design0/design0.toml"
-    assert path.exists()
     design = Design.from_toml(RESOURCES_DIR / "design0/design0.toml")
     settings = VivadoSynth.Settings(fpga=FPGA(part="abcd"), clock_period=5.5)  # type: ignore
     run_dir = Path.cwd() / "vivado_synth_run"
@@ -25,8 +23,8 @@ def test_vivado_synth_template() -> None:
     tcl_file = flow.copy_from_template(
         "vivado_synth.tcl",
         xdc_files=[],
-        reports_tcl="reports_tcl",
-        generics=" ".join(vivado_synth_generics(design)),
+        tcl_files=[],
+        generics=vivado_synth_generics(design.rtl.parameters),
     )
     with open(run_dir / tcl_file) as f:
         vivado_tcl = f.read()
@@ -38,16 +36,17 @@ def test_vivado_synth_template() -> None:
 
 
 def test_vivado_synth_py() -> None:
-    path = RESOURCES_DIR / "design0/design0.toml"
     # Append to PATH so if the actual tool exists, would take precedences.
-    os.environ["PATH"] += os.pathsep + os.path.join(TESTS_DIR, "fake_tools")
-    assert path.exists()
+    os.environ["PATH"] = (
+        os.path.join(TESTS_DIR, "fake_tools") + os.pathsep + os.environ.get("PATH", "")
+    )
     design = Design.from_toml(EXAMPLES_DIR / "vhdl" / "sqrt" / "sqrt.toml")
     settings = dict(fpga=FPGA("xc7a12tcsg325-1"), clock_period=5.5)
-    with tempfile.TemporaryDirectory() as run_dir:
+    with tempfile.TemporaryDirectory(dir=Path.cwd()) as run_dir:
         print("Xeda run dir: ", run_dir)
         xeda_runner = DefaultRunner(run_dir, debug=True)
         flow = xeda_runner.run_flow(VivadoSynth, design, settings)
+        assert flow is not None, "run_flow returned None"
         settings_json = flow.run_path / "settings.json"
         results_json = flow.run_path / "results.json"
         assert settings_json.exists()
